@@ -1,4 +1,4 @@
-"""dotnet module literals"""
+"""Angular module literals"""
 
 from devops_toolset.core.app import App
 from devops_toolset.core.ValueDictsBase import ValueDictsBase
@@ -10,6 +10,6 @@ class Literals(ValueDictsBase):
     """ValueDicts for the Angular module."""
 
     _info = {
-        "angular_project_version": "The project version is {version}",
+        "angular_project_version": _("The project version is {version}"),
     }
     _errors = {}
